#!/bin/bash
# A user-centric script for Bogofilter training from maildirs
#
# Copyright Joe Stroller 2003 stroller at bigfoot dot come
# and distributed under the GNU Public License

# Set up variables
MAILDIR="$HOME/.Maildir"
BOGODIR="$HOME/.bogofilter"
TOUCHFILE="$BOGODIR/bogoupdate.lastrun"

# These are the folders we want to exclude when scanning for new ham email
HAMEXCLUDEFOLDERS="*List* *Sent* *Trash* *Junk*"


# Saves me some typing, copying & pasting later
for folder in $HAMEXCLUDEFOLDERS
do
  HAMEXCLUDEARGS="$HAMEXCLUDEARGS -not -path $folder"
done


if [ ! -e $BOGODIR/wordlist.db ]
then
  if ( [ -e $BOGODIR/goodlist.db ] || [ -e $BOGODIR/spamlist.db ] )
  then 
    echo  "ERROR! This script requires Bogofilter >= v0.14 & uses a single wordlist file!"
    exit 1
  else
    if [ -e $TOUCHFILE ]
    then 
      echo "ERROR! This script has been run before, but no wordfile is found!"
      exit 1
    else # (no touchfile or wordlist, so start from fresh)
      echo "No touchfile or wordlist, so building bogoDB from fresh"
      echo "Scanning ham email folders..."

     #  Find all mail in sub-folders of Inbox, dropping special folders &
     #   mailing lists.
     # 	NB: From `man maildir`: "Folders are additional subdirectories in the
     #	 maildir whose names begin with a period: such as .Drafts or .Sent."
     #	 So we first drop anything NOT beginning with a period & then an
     #   alphanummeric like courierimap*, cur, new & tmp.

      find $MAILDIR -path "$MAILDIR/.[[:alpha:]]*/cur/*" \
	$HAMEXCLUDEARGS -print0 | xargs -0 bogofilter -n -W -v -B

      echo "Scanning spam email folder..."       # This one is easier to handle
      find $MAILDIR -path "$MAILDIR/.Junk.Definite/cur/*" \
	-print0 | xargs -0 bogofilter -s -W -v -B
      touch $TOUCHFILE
      exit 0
    fi
  fi
else
  if [ ! -e $TOUCHFILE ]
  then
    echo "ERROR! You've run Bogofilter before, but not using this script!"
    echo "Can't continue! Please update your spam & ham lists manually, then:"
    echo "  \`touch $TOUCHFILE\`"
    exit 1
  else
      echo "Scanning ham email folders for new messages..." 

     #  Find all mail in sub-folders of Inbox, dropping special folders &
     #   mailing lists, as per previous comments above.

      find $MAILDIR -path "$MAILDIR/.[[:alpha:]]*/cur/*" \
        $HAMEXCLUDEARGS -newer $TOUCHFILE \
	-print0 | xargs -0 bogofilter -n -W -v -B

      echo "Scanning spam email folder for new messages..."
      find $MAILDIR -path "$MAILDIR/.Junk.Definite/cur/*" \
        -newer $TOUCHFILE -print0 | xargs -0 bogofilter -s -W -v -B
	touch $TOUCHFILE
      exit 0

  fi
fi

